@@ -12,6 +12,7 @@ mod use_list;
 mod use_local_storage;
 mod use_location;
 mod use_map;
+mod use_measure;
 mod use_mount;
 mod use_previous;
 mod use_queue;
@@ -47,6 +48,7 @@ pub use use_list::*;
 pub use use_local_storage::*;
 pub use use_location::*;
 pub use use_map::*;
+pub use use_measure::*;
 pub use use_mount::*;
 pub use use_previous::*;
 pub use use_queue::*;
